.. _thread_handler_module:

:mod:`kazoo.handlers.threading`
-------------------------------

.. automodule:: kazoo.handlers.threading

Public API
++++++++++

    .. autoclass:: SequentialThreadingHandler
        :members:

Private API
+++++++++++

  .. autoclass:: AsyncResult
     :members:

  .. autoexception:: TimeoutError
